Module FfiNodeFactory_trait

Module FfiNodeFactory_trait 

This module is generated by the #[sabi_trait] attribute on FfiNodeFactory

Structs

FfiNodeFactory_Interface
A marker type describing the traits that are required when constructing FfiNodeFactory_TO,and are then implemented by it, by implementing the InterfaceType trait.
FfiNodeFactory_TO
The trait object for FfiNodeFactory.

Traits

FfiNodeFactory
FFI-safe factory — produces FfiNode instances from a JSON params blob.

Type Aliases

FfiNodeFactory_Backend
An alias for the underlying implementation of FfiNodeFactory_TO.
FfiNodeFactory_CTO
A type alias for the const-constructible FfiNodeFactory_TO.