Module FfiNode_trait

Module FfiNode_trait 

This module is generated by the #[sabi_trait] attribute on FfiNode

Structs

FfiNode_Interface
A marker type describing the traits that are required when constructing FfiNode_TO,and are then implemented by it, by implementing the InterfaceType trait.
FfiNode_TO
The trait object for FfiNode.

Traits

FfiNode
FFI-safe node.

Type Aliases

FfiNode_Backend
An alias for the underlying implementation of FfiNode_TO.
FfiNode_CTO
A type alias for the const-constructible FfiNode_TO.