Module OutputSink_trait

Module OutputSink_trait 

This module is generated by the #[sabi_trait] attribute on OutputSink

Structs

OutputSink_Interface
A marker type describing the traits that are required when constructing OutputSink_TO,and are then implemented by it, by implementing the InterfaceType trait.
OutputSink_TO
The trait object for OutputSink.

Traits

OutputSink
Per-frame output sink for streaming plugins.

Type Aliases

OutputSink_Backend
An alias for the underlying implementation of OutputSink_TO.
OutputSink_CTO
A type alias for the const-constructible OutputSink_TO.