FfiNode_TO

Struct FfiNode_TO 

#[repr(transparent)]
pub struct FfiNode_TO<_ErasedPtr>
where _ErasedPtr: __GetPointerKind,
{ pub obj: FfiNode_Backend<_ErasedPtr>, /* private fields */ }
The trait object for FfiNode.

There are extra methods on the obj field.

Fields

obj: FfiNode_Backend<_ErasedPtr>

Implementations

Source

impl<_ErasedPtr> FfiNode_TO<_ErasedPtr>
where _ErasedPtr: AsPtr<PtrTarget = ()>,

pub fn from_ptr<_OrigPtr, Downcasting>( ptr: _OrigPtr, can_it_downcast: Downcasting, ) -> Self
where _OrigPtr: CanTransmuteElement<(), TransmutedPtr = _ErasedPtr>, _OrigPtr::PtrTarget: FfiNode + Sized, FfiNode_Interface: GetRObjectVTable<Downcasting, _OrigPtr::PtrTarget, _ErasedPtr, _OrigPtr>,

Constructs this trait object from a pointer to a type that implements FfiNode.

This method is automatically generated, for more documentation you can look at abi_stable::docs::sabi_trait_inherent

can_it_downcast describes whether the trait object can be converted back into the original type or not.
Its possible values are TD_CanDowncast and TD_Opaque.

pub fn from_sabi(obj: FfiNode_Backend<_ErasedPtr>) -> Self

Constructs this trait object from its underlying implementation.

This method is automatically generated, for more documentation you can look at abi_stable::docs::sabi_trait_inherent

pub fn sabi_reborrow<'_sub>(&'_sub self) -> FfiNode_TO<RRef<'_sub, ()>>

Reborrows this trait object to a reference-based trait object.

This method is automatically generated, for more documentation you can look at abi_stable::docs::sabi_trait_inherent

pub fn sabi_reborrow_mut<'_sub>(&'_sub mut self) -> FfiNode_TO<RMut<'_sub, ()>>
where _ErasedPtr: AsMutPtr<PtrTarget = ()>,

Reborrows this trait object to a mutable-reference-based trait object.

This method is automatically generated, for more documentation you can look at abi_stable::docs::sabi_trait_inherent

Source

impl FfiNode_TO<RBox<()>>

pub fn from_value<_Self, Downcasting>( ptr: _Self, can_it_downcast: Downcasting, ) -> Self
where _Self: FfiNode, FfiNode_Interface: GetRObjectVTable<Downcasting, _Self, RBox<()>, RBox<_Self>>,

Constructs this trait from a type that implements FfiNode.

This method is automatically generated, for more documentation you can look at abi_stable::docs::sabi_trait_inherent

can_it_downcast describes whether the trait object can be converted back into the original type or not.
Its possible values are TD_CanDowncast and TD_Opaque.

Source

impl<'_sub> FfiNode_TO<RRef<'_sub, ()>>

pub const fn from_const<_Self, Downcasting>( ptr: &'_sub _Self, can_it_downcast: Downcasting, ) -> Self
where _Self: FfiNode + 'static, FfiNode_Interface: GetRObjectVTable<Downcasting, _Self, RRef<'_sub, ()>, &'_sub _Self>,

Constructs this trait from a constant of a type that implements FfiNode.

This method is automatically generated, for more documentation you can look at abi_stable::docs::sabi_trait_inherent

You can construct the vtable_for parameter with [FfiNode_MV::VTABLE].

can_it_downcast describes whether the trait object can be converted back into the original type or not.
Its possible values are TD_CanDowncast and TD_Opaque.

Source

impl<_ErasedPtr> FfiNode_TO<_ErasedPtr>
where _ErasedPtr: AsPtr<PtrTarget = ()>, Self: Send + Sync,

pub fn node_type(&self) -> RString
where _ErasedPtr: AsPtr<PtrTarget = ()>,

This is the inherent equivalent of the trait method of the same name

pub fn process( &self, param_0: RVec<u8>, ) -> FfiFuture<RResult<RVec<u8>, RString>>
where _ErasedPtr: AsPtr<PtrTarget = ()>,

This is the inherent equivalent of the trait method of the same name

pub fn process_multi( &self, param_0: RVec<u8>, ) -> FfiFuture<RResult<RVec<RVec<u8>>, RString>>
where _ErasedPtr: AsPtr<PtrTarget = ()>,

This is the inherent equivalent of the trait method of the same name

pub fn process_streaming( &self, param_0: RVec<u8>, param_1: OutputSinkBox, ) -> FfiFuture<RResult<usize, RString>>
where _ErasedPtr: AsPtr<PtrTarget = ()>,

This is the inherent equivalent of the trait method of the same name

pub fn initialize( &self, param_0: RString, param_1: RString, ) -> FfiFuture<RResult<(), RString>>
where _ErasedPtr: AsPtr<PtrTarget = ()>,

This is the inherent equivalent of the trait method of the same name