This module is generated by the #[sabi_trait] attribute on FfiNodeFactory
Structs
- FfiNode
Factory_ Interface - A marker type describing the traits that are required when constructing
FfiNodeFactory_TO,and are then implemented by it, by implementing theInterfaceTypetrait. - FfiNode
Factory_ TO - The trait object for FfiNodeFactory.
Traits
- FfiNode
Factory - FFI-safe factory — produces FfiNode instances from a JSON params blob.
Type Aliases
- FfiNode
Factory_ Backend - An alias for the underlying implementation of
FfiNodeFactory_TO. - FfiNode
Factory_ CTO - A type alias for the const-constructible
FfiNodeFactory_TO.