This module is generated by the #[sabi_trait] attribute on FfiNode
Structs
- FfiNode_
Interface - A marker type describing the traits that are required when constructing
FfiNode_TO,and are then implemented by it, by implementing theInterfaceTypetrait. - FfiNode_
TO - The trait object for FfiNode.
Traits
- FfiNode
- FFI-safe node.
Type Aliases
- FfiNode_
Backend - An alias for the underlying implementation of
FfiNode_TO. - FfiNode_
CTO - A type alias for the const-constructible
FfiNode_TO.