pub type FfiNodeBox = FfiNode_TO<RBox<()>>;Expand description
Owned trait object for an FFI node.
sabi_trait drops the lifetime parameter when the trait has a
'static bound, so the alias does not name a lifetime.
Aliased Type
#[repr(transparent)]pub struct FfiNodeBox {
pub obj: RObject<'static, RBox<()>, FfiNode_Interface, VTable_Prefix<(), RBox<()>>>,
/* private fields */
}Fields
obj: RObject<'static, RBox<()>, FfiNode_Interface, VTable_Prefix<(), RBox<()>>>